/**
 * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'en', {
	button: 'Insert Code Snippet',
	codeContents: 'Code content',
	emptySnippetError: 'A code snippet cannot be empty.',
	language: 'Language',
	title: 'Code snippet',
	pathName: 'code snippet'
} );
